@@ -117,7 +117,7 @@ def _processDataStream(output_queue, shutdown_flag, connected_flag, host, port):
 	#debug('Attempting to connect to headset...')
 	while not connected_flag.isSet():
 		flat_dict = next_message()
-		if not raw_data == NULL_DATA:
+		if not flat_dict == NULL_DATA:
 			# getting real data now
 			connected_flag.set()
 	# should now be getting real data
